// Generated by dts-bundle-generator v9.5.1

export declare class SocketError extends Error {
	name: string;
	originalError?: Error | ErrorEvent;
	constructor(message: string, originalError?: Error | ErrorEvent);
}
export type SocketDataHandler = (data: unknown) => void | Promise<void>;
export type SocketErrorHandler = (error: SocketError) => void;
export type SocketConnectedHandler = () => void;
export type SocketDisconnectedHandler = ({ wasClean, code, reason, }: {
	wasClean: boolean;
	code: number;
	reason: string;
}) => void;
export interface HandlerDefinitions {
	onMessage?: SocketDataHandler;
	onError?: SocketErrorHandler;
	onConnected?: SocketConnectedHandler;
	onDisconnected?: SocketDisconnectedHandler;
}
export declare class ManagedSocket {
	readonly url: string;
	socket: WebSocket;
	onMessage: SocketDataHandler;
	onError: SocketErrorHandler;
	onConnected: SocketConnectedHandler;
	onDisconnected: SocketDisconnectedHandler;
	private _reconnectAttempts;
	private _messageQueue;
	private _debugMode;
	private _offline;
	constructor(url: string, handlers?: HandlerDefinitions);
	private heartbeat;
	private debugMessage;
	private sendQueuedMessages;
	private attemptReconnection;
	private connect;
	get isConnected(): boolean;
	debug(debugModeEnabled: boolean): void;
	close(): void;
	send<T>(data: T): void;
}
export type SocketHeartbeatMessage = [
	"heartbeat",
	number
];
export type SocketDataMessage<T = unknown> = [
	"data",
	T
];
/**
 * Creates a socket data message object with the given data.
 *
 * @param data - The data to be included in the message. Can be of any type.
 * @returns An object representing the socket data message with a type of "message" and the provided data.
 */
export declare function wrap(data: unknown): SocketDataMessage;
/**
 * Extracts the data from a SocketDataMessage.
 *
 * @param message - The socket data message to extract data from.
 * @returns The data contained in the message.
 */
export declare function unwrap<T = unknown>(message: SocketDataMessage<T>): T;
/**
 * Deserializes a JSON string into a `SocketMessage` object.
 *
 * @param data - The JSON string to be deserialized.
 * @returns The deserialized `SocketMessage` object.
 * @throws {ManagedSocketError} If the JSON string cannot be parsed or if the message shape is invalid.
 */
export declare function deserialize<T>(data: string): SocketDataMessage<T> | SocketHeartbeatMessage;

export {};
